Combined emphasis:

1. test test
2. test test
3. test test
4. test test
5. test test
6. test test
7. test test
8. test test
9. test test
10. test test
11. test test
12. test test
13. test test
14. test test
15. test test
16. test test

Incorrect nesting:

1. *test test* test
2. _test test_ test
3. **test test* test*
4. __test test_ test_
5. test *test test*
6. test _test test_
7. test test test
8. test test test

No emphasis:

1. test* test *test
2. test** test **test
3. test_ test _test
4. test__ test __test

Middle-word emphasis (asterisks):

1. ab
2. ab
3. abc
4. ab
5. ab
6. abc

Middle-word emphasis (underscore):

1. _a_b
2. a_b_
3. a_b_c
4. __a__b
5. a__b__
6. a__b__c

my_precious_file.txt

## Tricky Cases

E**. Test TestTestTest

E**. Test Test Test Test